pub fn retpoline_features_by_flags(
sess: &EarlySession,
features: &mut Vec<String>,
)Expand description
Computes the backend target features to be added to account for retpoline flags. Used by both LLVM and GCC since their target features are, conveniently, the same.