pub fn sanitizer_features_by_flags(
sess: &EarlySession,
features: &mut Vec<String>,
)Expand description
Computes the backend target features to be added to account for sanitizer flags.
pub fn sanitizer_features_by_flags(
sess: &EarlySession,
features: &mut Vec<String>,
)Computes the backend target features to be added to account for sanitizer flags.